Function init_thread_pool
pub fn init_thread_pool(num_threads: usize) -> Result<(), ThreadPoolBuildError>Expand description
Initialize the Rayon thread pool with the given number of threads.
Also initializes the queue limit metric.
pub fn init_thread_pool(num_threads: usize) -> Result<(), ThreadPoolBuildError>Initialize the Rayon thread pool with the given number of threads.
Also initializes the queue limit metric.